@@ -16,7 +16,7 @@ use File::Path;
 use File::Spec::Functions qw(catdir catfile devnull path);
 use File::Temp qw(tempfile);
 
-our $VERSION = "0.83";
+our $VERSION = "0.84";
 
 my %_CMD_LOC_FOR = ();
 
@@ -47,14 +47,19 @@ Archive::Probe - A generic library to search file within archive
 
 Archive::Probe is a generic library to search file within archive.
 
-It allows you to test the existence of a particular file, which can be
-described in regular expression, and optionally to extract that file and
-inspect the file content in custom code. It supports common archive types
-such as .tar, .tgz, .bz2, .rar, .zip, .7z. One archive file can contain
-archive file of same or other type. And level of nesting is unlimited.
-This module depends on unrar, 7za and tar which should be in PATH.
-The 7za is part of open source software 7zip. You can get it from:
-www.7-zip.org. The unrar is freeware which can be downloaded from:
+It facilitates searching of particular file by name or content inside
+deeply nested archive with mixed types. It supports common archive
+types such as .tar, .tgz, .bz2, .rar, .zip .7z and Java archive such
+as .jar, .war, .ear. If the target archive file contains another
+archive file of same or other type, this module extracts the embedded
+archive to fulfill the inquiry. The level of embedding is unlimited.
+This module depends on unzip, unrar, 7za and tar which are assumed to
+be present in PATH. The 7za is part of 7zip utility. It is preferred
+tool to deal with .zip archive it runs faster and handles meta
+character better than unzip. The 7zip is open source software and you
+download and install it from www.7-zip.org or install the binary
+package p7zip with your favorite package management software. The
+unrar is freeware which can be downloaded from
 http://www.rarlab.com/rar_add.htm.
 
 =cut
@@ -189,7 +194,7 @@ sub working_dir {
     return $self->{working_dir};
 }
 
-=head2 show_extracting_output[BOOL])
+=head2 show_extracting_output([BOOL])
 
 Enable or disable the output of command line archive tool.
 
@@ -225,7 +230,7 @@ sub _extract_matched {
             );
             if (!$ret) {
                 carp("$file can not be extracted from $parent, ignored\n");
-                return undef;
+                return;
             }
         }
         $dest = catfile($extract_dir, $file);
@@ -243,7 +248,7 @@ sub _extract_matched {
             my $ret = copy($file, $dest);
             if (!$ret) {
                 carp("Can't copy file $file to $dest due to: $!\n");
-                return undef;
+                return;
             }
         }
     }
@@ -328,7 +333,7 @@ sub _walk_tree {
 sub _search_in_archive {
     my ($self, $do_extract, $base_dir, $ctx, $file) = @_;
 
-    if ($file =~ /\.zip$/) {
+    if ($file =~ /\.zip$|\.jar$|\.war$|\.ear$/) {
         if ($self->_is_cmd_avail('7za')) {
             $self->_peek_archive(
                 $do_extract,
@@ -342,12 +347,12 @@ sub _search_in_archive {
                 sub {
                     my ($entry, undef, undef, undef, undef, $file_pos) = @_;
                     my (undef, undef, $a, undef) = split(' ', $entry, 4);
-                    return undef if $a =~ /^D/;
+                    return if $a =~ /^D/;
                     if ($file_pos && $file_pos < length($entry)) {
                        my $f = substr($entry, $file_pos);
                        return $f;
                     }
-                    return undef;
+                    return;
                 }
             ); 
         }
@@ -383,12 +388,12 @@ sub _search_in_archive {
             sub {
                 my ($entry, undef, undef, undef, undef, $file_pos_7z) = @_;
                 my (undef, undef, $a, undef) = split(' ', $entry, 4);
-                return undef if $a =~ /^D/;
+                return if $a =~ /^D/;
                 if ($file_pos_7z && $file_pos_7z < length($entry)) {
                    my $f = substr($entry, $file_pos_7z);
                    return $f;
                 }
-                return undef;
+                return;
             }
         ); 
     }
@@ -490,7 +495,7 @@ sub _peek_archive {
         carp("Can't run $cmd due to: $!\n");
         return;
     }
-    $ret = open(my $fh, "<$lst_file");
+    $ret = open(my $fh, q{<}, "$lst_file");
     if (!$ret) {
         carp("Can't open file $lst_file due to: $!\n");
         return;
@@ -555,7 +560,7 @@ sub _extract_archive_file {
 
     mkpath($extract_dir) unless -d $extract_dir;
     my $cmd = "";
-    if ($parent =~ /\.zip$/) {
+    if ($parent =~ /\.zip$|\.jar$|\.war$|\.ear$/) {
         if ($self->_is_cmd_avail('7za')) {
             # specify dummy password to make 7za fail fast
             # instead of waiting for user input password when
@@ -602,7 +607,7 @@ sub _extract_archive_file {
             }
         }
     }
-    elsif ($parent =~ /\.zip$|\.7z$/) {
+    elsif ($parent =~ /\.7z$/) {
         # specify dummy password to make 7za fail fast
         # instead of waiting for user input password when
         # the zip file is password-protected
@@ -737,7 +742,7 @@ sub _escape {
 sub _is_archive_file {
     my ($self, $file) = @_;
 
-    return $file =~ /\.(zip|7z|rar|tgz|bz2|tar|tar\.gz|tar\.Z)$/
+    return $file =~ /\.(zip|jar|war|ear|7z|rar|tgz|bz2|tar|tar\.gz|tar\.Z)$/
 }
 
 sub _property {
@@ -755,7 +760,7 @@ sub _property {
     return $self->{$attr};
 }
 
-sub _remove_property ($$) {
+sub _remove_property {
     my ($self, $attr) = @_;
 
     $self->{$attr} = undef;
@@ -821,7 +826,7 @@ to fulfill the inquiry.
 
 =head1 SOURCE AVAILABILITY
 
-This code is in Github
+This code is hosted on Github
 
     https://github.com/schnell18/archive-probe
 
